/*----- PROTECTED REGION ID(SeqUtils.cpp) ENABLED START -----*/
//=============================================================================
//
// file :        SeqUtils.cpp
//
// description : C++ source for the SeqUtils class and its commands.
//               The class is derived from Device. It represents the
//               CORBA servant object which will be accessed from the
//               network. All commands which can be executed on the
//               SeqUtils are implemented in this file.
//
// project :     SeqUtils
//
// This file is part of Tango device class.
// 
// Tango is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// Tango is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with Tango.  If not, see <http://www.gnu.org/licenses/>.
// 
//
//
//=============================================================================
//                This file is generated by POGO
//        (Program Obviously used to Generate tango Object)
//=============================================================================


#include <SeqUtils.h>
#include <SeqUtilsClass.h>
#include <stdio.h>
#include <time.h>

/*----- PROTECTED REGION END -----*/	//	SeqUtils.cpp

/**
 *  SeqUtils class description:
 *    It returns a random generated number, sec/nsec date
 */

//================================================================
//  The following table gives the correspondence
//  between command and method names.
//
//  Command name  |  Method name
//================================================================
//  State         |  Inherited (no method)
//  Status        |  Inherited (no method)
//  On            |  on
//  Off           |  off
//  Reset         |  reset
//  SetFault      |  set_fault
//  Start         |  start
//  Stop          |  stop
//================================================================

//================================================================
//  Attributes managed are:
//================================================================
//  DRand     |  Tango::DevDouble	Scalar
//  DRandMin  |  Tango::DevDouble	Scalar
//  DRandMax  |  Tango::DevDouble	Scalar
//  LRand     |  Tango::DevLong	Scalar
//  LRandMin  |  Tango::DevLong	Scalar
//  LRandMax  |  Tango::DevLong	Scalar
//  Data      |  Tango::DevDouble	Scalar
//  Data1     |  Tango::DevDouble	Scalar
//  LData     |  Tango::DevLong	Scalar
//  Date      |  Tango::DevLong	Spectrum  ( max = 2)
//  LDate     |  Tango::DevLong	Spectrum  ( max = 2)
//================================================================

namespace SeqUtils_ns
{
/*----- PROTECTED REGION ID(SeqUtils::namespace_starting) ENABLED START -----*/

//	static initializations

/*----- PROTECTED REGION END -----*/	//	SeqUtils::namespace_starting

//--------------------------------------------------------
/**
 *	Method      : SeqUtils::SeqUtils()
 *	Description : Constructors for a Tango device
 *                implementing the classSeqUtils
 */
//--------------------------------------------------------
SeqUtils::SeqUtils(Tango::DeviceClass *cl, string &s)
 : TANGO_BASE_CLASS(cl, s.c_str())
{
	/*----- PROTECTED REGION ID(SeqUtils::constructor_1) ENABLED START -----*/
	init_device();
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::constructor_1
}
//--------------------------------------------------------
SeqUtils::SeqUtils(Tango::DeviceClass *cl, const char *s)
 : TANGO_BASE_CLASS(cl, s)
{
	/*----- PROTECTED REGION ID(SeqUtils::constructor_2) ENABLED START -----*/
	init_device();
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::constructor_2
}
//--------------------------------------------------------
SeqUtils::SeqUtils(Tango::DeviceClass *cl, const char *s, const char *d)
 : TANGO_BASE_CLASS(cl, s, d)
{
	/*----- PROTECTED REGION ID(SeqUtils::constructor_3) ENABLED START -----*/
	init_device();
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::constructor_3
}

//--------------------------------------------------------
/**
 *	Method      : SeqUtils::delete_device()
 *	Description : will be called at device destruction or at init command
 */
//--------------------------------------------------------
void SeqUtils::delete_device()
{
	DEBUG_STREAM << "SeqUtils::delete_device() " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::delete_device) ENABLED START -----*/
	
	//	Delete device allocated objects
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::delete_device
	delete[] attr_DRand_read;
	delete[] attr_DRandMin_read;
	delete[] attr_DRandMax_read;
	delete[] attr_LRand_read;
	delete[] attr_LRandMin_read;
	delete[] attr_LRandMax_read;
	delete[] attr_Data_read;
	delete[] attr_Data1_read;
	delete[] attr_LData_read;
	delete[] attr_Date_read;
	delete[] attr_LDate_read;
}

//--------------------------------------------------------
/**
 *	Method      : SeqUtils::init_device()
 *	Description : will be called at device initialization.
 */
//--------------------------------------------------------
void SeqUtils::init_device()
{
	DEBUG_STREAM << "SeqUtils::init_device() create device " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::init_device_before) ENABLED START -----*/
	
	//	Initialization before get_device_property() call
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::init_device_before
	
	//	No device property to be read from database
	
	attr_DRand_read = new Tango::DevDouble[1];
	attr_DRandMin_read = new Tango::DevDouble[1];
	attr_DRandMax_read = new Tango::DevDouble[1];
	attr_LRand_read = new Tango::DevLong[1];
	attr_LRandMin_read = new Tango::DevLong[1];
	attr_LRandMax_read = new Tango::DevLong[1];
	attr_Data_read = new Tango::DevDouble[1];
	attr_Data1_read = new Tango::DevDouble[1];
	attr_LData_read = new Tango::DevLong[1];
	attr_Date_read = new Tango::DevLong[2];
	attr_LDate_read = new Tango::DevLong[2];
	/*----- PROTECTED REGION ID(SeqUtils::init_device) ENABLED START -----*/
	
	//	Initialize device
	*attr_DRandMin_read = -1;
	*attr_DRandMax_read = 1;
	*attr_LRandMin_read = -2147483646;
	*attr_LRandMax_read = 2147483647;

	*attr_LData_read = 0;
	*attr_Data_read = 0;
	*attr_Data1_read = 0;

	set_state(Tango::ON);
	srand(time(NULL));
	

	/*----- PROTECTED REGION END -----*/	//	SeqUtils::init_device
}


//--------------------------------------------------------
/**
 *	Method      : SeqUtils::always_executed_hook()
 *	Description : method always executed before any command is executed
 */
//--------------------------------------------------------
void SeqUtils::always_executed_hook()
{
	DEBUG_STREAM << "SeqUtils::always_executed_hook()  " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::always_executed_hook) ENABLED START -----*/
	
	//	code always executed before all requests
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::always_executed_hook
}

//--------------------------------------------------------
/**
 *	Method      : SeqUtils::read_attr_hardware()
 *	Description : Hardware acquisition for attributes
 */
//--------------------------------------------------------
void SeqUtils::read_attr_hardware(TANGO_UNUSED(vector<long> &attr_list))
{
	DEBUG_STREAM << "SeqUtils::read_attr_hardware(vector<long> &attr_list) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_attr_hardware) ENABLED START -----*/
	
	//	Add your own code
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_attr_hardware
}
//--------------------------------------------------------
/**
 *	Method      : SeqUtils::write_attr_hardware()
 *	Description : Hardware writing for attributes
 */
//--------------------------------------------------------
void SeqUtils::write_attr_hardware(TANGO_UNUSED(vector<long> &attr_list))
{
	DEBUG_STREAM << "SeqUtils::write_attr_hardware(vector<long> &attr_list) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::write_attr_hardware) ENABLED START -----*/
	
	//	Add your own code
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_attr_hardware
}

//--------------------------------------------------------
/**
 *	Read attribute DRand related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_DRand(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_DRand(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_DRand) ENABLED START -----*/
	//	Set the attribute value

	double a = ((double)rand() / (double)RAND_MAX);
	INFO_STREAM << __FUNCTION__ << " rand value: " << a << endl;
	

	*attr_DRand_read = a * (*attr_DRandMax_read-*attr_DRandMin_read) + 
		*attr_DRandMin_read;
	attr.set_value(attr_DRand_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_DRand
}
//--------------------------------------------------------
/**
 *	Read attribute DRandMin related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_DRandMin(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_DRandMin(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_DRandMin) ENABLED START -----*/
	//	Set the attribute value

	attr.set_value(attr_DRandMin_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_DRandMin
}
//--------------------------------------------------------
/**
 *	Write attribute DRandMin related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::write_DRandMin(Tango::WAttribute &attr)
{
	DEBUG_STREAM << "SeqUtils::write_DRandMin(Tango::WAttribute &attr) entering... " << endl;
	//	Retrieve write value
	Tango::DevDouble	w_val;
	attr.get_write_value(w_val);
	/*----- PROTECTED REGION ID(SeqUtils::write_DRandMin) ENABLED START -----*/
	*attr_DRandMin_read = w_val;
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_DRandMin
}
//--------------------------------------------------------
/**
 *	Read attribute DRandMax related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_DRandMax(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_DRandMax(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_DRandMax) ENABLED START -----*/
	//	Set the attribute value
	attr.set_value(attr_DRandMax_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_DRandMax
}
//--------------------------------------------------------
/**
 *	Write attribute DRandMax related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::write_DRandMax(Tango::WAttribute &attr)
{
	DEBUG_STREAM << "SeqUtils::write_DRandMax(Tango::WAttribute &attr) entering... " << endl;
	//	Retrieve write value
	Tango::DevDouble	w_val;
	attr.get_write_value(w_val);
	/*----- PROTECTED REGION ID(SeqUtils::write_DRandMax) ENABLED START -----*/
	*attr_DRandMax_read = w_val;
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_DRandMax
}
//--------------------------------------------------------
/**
 *	Read attribute LRand related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_LRand(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_LRand(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_LRand) ENABLED START -----*/
	//	Set the attribute value
	Tango::DevLong a = (Tango::DevLong)rand();
	INFO_STREAM << __FUNCTION__ << " rand value: " << a << endl;


	*attr_LRand_read = (a %(*attr_LRandMax_read-*attr_LRandMin_read+1))+*attr_LRandMin_read;
	attr.set_value(attr_LRand_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_LRand
}
//--------------------------------------------------------
/**
 *	Read attribute LRandMin related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_LRandMin(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_LRandMin(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_LRandMin) ENABLED START -----*/
	//	Set the attribute value
	attr.set_value(attr_LRandMin_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_LRandMin
}
//--------------------------------------------------------
/**
 *	Write attribute LRandMin related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::write_LRandMin(Tango::WAttribute &attr)
{
	DEBUG_STREAM << "SeqUtils::write_LRandMin(Tango::WAttribute &attr) entering... " << endl;
	//	Retrieve write value
	Tango::DevLong	w_val;
	attr.get_write_value(w_val);
	/*----- PROTECTED REGION ID(SeqUtils::write_LRandMin) ENABLED START -----*/
	*attr_LRandMin_read = w_val;
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_LRandMin
}
//--------------------------------------------------------
/**
 *	Read attribute LRandMax related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_LRandMax(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_LRandMax(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_LRandMax) ENABLED START -----*/
	//	Set the attribute value
	attr.set_value(attr_LRandMax_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_LRandMax
}
//--------------------------------------------------------
/**
 *	Write attribute LRandMax related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::write_LRandMax(Tango::WAttribute &attr)
{
	DEBUG_STREAM << "SeqUtils::write_LRandMax(Tango::WAttribute &attr) entering... " << endl;
	//	Retrieve write value
	Tango::DevLong	w_val;
	attr.get_write_value(w_val);
	/*----- PROTECTED REGION ID(SeqUtils::write_LRandMax) ENABLED START -----*/
		*attr_LRandMax_read = w_val;
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_LRandMax
}
//--------------------------------------------------------
/**
 *	Read attribute Data related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_Data(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_Data(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_Data) ENABLED START -----*/
	//	Set the attribute value
	attr.set_value(attr_Data_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_Data
}
//--------------------------------------------------------
/**
 *	Write attribute Data related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::write_Data(Tango::WAttribute &attr)
{
	DEBUG_STREAM << "SeqUtils::write_Data(Tango::WAttribute &attr) entering... " << endl;
	//	Retrieve write value
	Tango::DevDouble	w_val;
	attr.get_write_value(w_val);
	/*----- PROTECTED REGION ID(SeqUtils::write_Data) ENABLED START -----*/
	*attr_Data_read = w_val;
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_Data
}
//--------------------------------------------------------
/**
 *	Read attribute Data1 related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_Data1(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_Data1(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_Data1) ENABLED START -----*/
	//	Set the attribute value
	attr.set_value(attr_Data1_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_Data1
}
//--------------------------------------------------------
/**
 *	Write attribute Data1 related method
 *	Description: 
 *
 *	Data type:	Tango::DevDouble
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::write_Data1(Tango::WAttribute &attr)
{
	DEBUG_STREAM << "SeqUtils::write_Data1(Tango::WAttribute &attr) entering... " << endl;
	//	Retrieve write value
	Tango::DevDouble	w_val;
	attr.get_write_value(w_val);
	/*----- PROTECTED REGION ID(SeqUtils::write_Data1) ENABLED START -----*/
	
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_Data1
}
//--------------------------------------------------------
/**
 *	Read attribute LData related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::read_LData(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_LData(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_LData) ENABLED START -----*/
	//	Set the attribute value
	attr.set_value(attr_LData_read);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_LData
}
//--------------------------------------------------------
/**
 *	Write attribute LData related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Scalar
 */
//--------------------------------------------------------
void SeqUtils::write_LData(Tango::WAttribute &attr)
{
	DEBUG_STREAM << "SeqUtils::write_LData(Tango::WAttribute &attr) entering... " << endl;
	//	Retrieve write value
	Tango::DevLong	w_val;
	attr.get_write_value(w_val);
	/*----- PROTECTED REGION ID(SeqUtils::write_LData) ENABLED START -----*/
	
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::write_LData
}
//--------------------------------------------------------
/**
 *	Read attribute Date related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Spectrum max = 2
 */
//--------------------------------------------------------
void SeqUtils::read_Date(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_Date(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_Date) ENABLED START -----*/
	//	Set the attribute value
	struct timespec t0;
	clock_gettime(CLOCK_REALTIME, &t0);

	attr_Date_read[0] = (Tango::DevLong) t0.tv_sec;
	attr_Date_read[1] = (Tango::DevLong) t0.tv_nsec;

	attr.set_value(attr_Date_read, 2);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_Date
}
//--------------------------------------------------------
/**
 *	Read attribute LDate related method
 *	Description: 
 *
 *	Data type:	Tango::DevLong
 *	Attr type:	Spectrum max = 2
 */
//--------------------------------------------------------
void SeqUtils::read_LDate(Tango::Attribute &attr)
{
	DEBUG_STREAM << "SeqUtils::read_LDate(Tango::Attribute &attr) entering... " << endl;
	/*----- PROTECTED REGION ID(SeqUtils::read_LDate) ENABLED START -----*/
	//	Set the attribute value
	struct timespec t0;
	clock_gettime(CLOCK_REALTIME, &t0);

	attr_LDate_read[0] = (Tango::DevLong64) t0.tv_sec;
	attr_LDate_read[1] = (Tango::DevLong64) t0.tv_nsec;

	attr.set_value(attr_LDate_read, 2);
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::read_LDate
}

//--------------------------------------------------------
/**
 *	Method      : SeqUtils::add_dynamic_attributes()
 *	Description : Create the dynamic attributes if any
 *                for specified device.
 */
//--------------------------------------------------------
void SeqUtils::add_dynamic_attributes()
{
	/*----- PROTECTED REGION ID(SeqUtils::add_dynamic_attributes) ENABLED START -----*/
	
	//	Add your own code to create and add dynamic attributes if any
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::add_dynamic_attributes
}

//--------------------------------------------------------
/**
 *	Command On related method
 *	Description: 
 *
 */
//--------------------------------------------------------
void SeqUtils::on()
{
	DEBUG_STREAM << "SeqUtils::On()  - " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::on) ENABLED START -----*/
	
	//	Add your own code
	set_state(Tango::ON);
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::on
}
//--------------------------------------------------------
/**
 *	Command Off related method
 *	Description: 
 *
 */
//--------------------------------------------------------
void SeqUtils::off()
{
	DEBUG_STREAM << "SeqUtils::Off()  - " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::off) ENABLED START -----*/
	
	//	Add your own code
	*attr_Data_read = 0;
	*attr_Data1_read = 0;
	set_state(Tango::OFF);
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::off
}
//--------------------------------------------------------
/**
 *	Command Reset related method
 *	Description: 
 *
 */
//--------------------------------------------------------
void SeqUtils::reset()
{
	DEBUG_STREAM << "SeqUtils::Reset()  - " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::reset) ENABLED START -----*/
	
	//	Add your own code
	*attr_Data_read = 0;
	*attr_Data1_read = 0;
	set_state(Tango::OFF);
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::reset
}
//--------------------------------------------------------
/**
 *	Command SetFault related method
 *	Description: 
 *
 */
//--------------------------------------------------------
void SeqUtils::set_fault()
{
	DEBUG_STREAM << "SeqUtils::SetFault()  - " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::set_fault) ENABLED START -----*/
	
	//	Add your own code
	*attr_Data_read = 0;
	*attr_Data1_read = 0;
	set_state(Tango::FAULT);
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::set_fault
}
//--------------------------------------------------------
/**
 *	Command Start related method
 *	Description: 
 *
 */
//--------------------------------------------------------
void SeqUtils::start()
{
	DEBUG_STREAM << "SeqUtils::Start()  - " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::start) ENABLED START -----*/
	
	//	Add your own code
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::start
}
//--------------------------------------------------------
/**
 *	Command Stop related method
 *	Description: 
 *
 */
//--------------------------------------------------------
void SeqUtils::stop()
{
	DEBUG_STREAM << "SeqUtils::Stop()  - " << device_name << endl;
	/*----- PROTECTED REGION ID(SeqUtils::stop) ENABLED START -----*/
	
	//	Add your own code
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::stop
}
//--------------------------------------------------------
/**
 *	Method      : SeqUtils::add_dynamic_commands()
 *	Description : Create the dynamic commands if any
 *                for specified device.
 */
//--------------------------------------------------------
void SeqUtils::add_dynamic_commands()
{
	/*----- PROTECTED REGION ID(SeqUtils::add_dynamic_commands) ENABLED START -----*/
	
	//	Add your own code to create and add dynamic commands if any
	
	/*----- PROTECTED REGION END -----*/	//	SeqUtils::add_dynamic_commands
}

/*----- PROTECTED REGION ID(SeqUtils::namespace_ending) ENABLED START -----*/

//	Additional Methods
// //--------------------------------------------------------
// /**
//  *	Command Standby related method
//  *	Description: 
//  *
//  */
// //--------------------------------------------------------
// void SeqUtils::standby()
// {
// 	DEBUG_STREAM << "SeqUtils::Standby()  - " << device_name << endl;
// 	
// 	//	Add your own code
// 	set_state(Tango::STANDBY);
// }


/*----- PROTECTED REGION END -----*/	//	SeqUtils::namespace_ending
} //	namespace
